@@ -129,6 +129,11 @@ def write_default_ansible_cfg(work_dir,
     config.set('defaults', 'fact_caching', 'jsonfile')
     config.set('defaults', 'fact_caching_connection',
                '~/.ansible/fact_cache')
+    # NOTE(mwhahaha): only gather the bare minimum facts because this has
+    # direct impact on how fast ansible can go.
+    config.set('defaults', 'gather_subset', '!all,min')
+    # NOTE(mwhahaha): this significantly affects performation per ansible#73654
+    config.set('defaults', 'inject_facts_as_vars', 'false')
 
     # Set the pull interval to lower CPU overhead
     config.set('defaults', 'internal_poll_interval', '0.05')
