@@ -627,6 +627,7 @@ class TestUndeployInstance(base.TestCase):
     def test_success(self, mock_pr):
         pr = mock_pr.return_value
         action = baremetal_deploy.UndeployInstanceAction('inst1')
+        # pylint: disable=assignment-from-none
         result = action.run(mock.Mock())
         self.assertIsNone(result)
 
@@ -638,6 +639,7 @@ class TestUndeployInstance(base.TestCase):
         pr = mock_pr.return_value
         pr.show_instance.side_effect = RuntimeError('not found')
         action = baremetal_deploy.UndeployInstanceAction('inst1')
+        # pylint: disable=assignment-from-none
         result = action.run(mock.Mock())
         self.assertIsNone(result)
 
@@ -664,12 +666,12 @@ class TestExpandRoles(base.TestCase):
             result['instances'])
         self.assertEqual(
             {
-                'ComputeDeployedServerHostnameFormat':
+                'ComputeHostnameFormat':
                 '%stackname%-novacompute-%index%',
-                'ComputeDeployedServerCount': 1,
-                'ControllerDeployedServerHostnameFormat':
+                'ComputeCount': 1,
+                'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
-                'ControllerDeployedServerCount': 1,
+                'ControllerCount': 1,
                 'HostnameMap': {
                     'overcloud-novacompute-0': 'overcloud-novacompute-0',
                     'overcloud-controller-0': 'overcloud-controller-0'
@@ -743,12 +745,12 @@ class TestExpandRoles(base.TestCase):
             result['instances'])
         self.assertEqual(
             {
-                'ComputeDeployedServerHostnameFormat':
+                'ComputeHostnameFormat':
                 'compute-%index%.example.com',
-                'ComputeDeployedServerCount': 2,
-                'ControllerDeployedServerHostnameFormat':
+                'ComputeCount': 2,
+                'ControllerHostnameFormat':
                 'controller-%index%.example.com',
-                'ControllerDeployedServerCount': 3,
+                'ControllerCount': 3,
                 'HostnameMap': {
                     'compute-0.example.com': 'compute-0.example.com',
                     'compute-1.example.com': 'compute-1.example.com',
@@ -802,12 +804,12 @@ class TestExpandRoles(base.TestCase):
             result['instances'])
         self.assertEqual(
             {
-                'ComputeDeployedServerHostnameFormat':
+                'ComputeHostnameFormat':
                 'compute-%index%.example.com',
-                'ComputeDeployedServerCount': 2,
-                'ControllerDeployedServerHostnameFormat':
+                'ComputeCount': 2,
+                'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
-                'ControllerDeployedServerCount': 2,
+                'ControllerCount': 2,
                 'HostnameMap': {
                     'compute-0.example.com': 'compute-0.example.com',
                     'compute-1.example.com': 'compute-1.example.com',
@@ -869,11 +871,11 @@ class TestExpandRoles(base.TestCase):
             }],
             result['instances'])
         self.assertEqual({
-            'ComputeDeployedServerCount': 2,
-            'ComputeDeployedServerHostnameFormat':
+            'ComputeCount': 2,
+            'ComputeHostnameFormat':
                 'compute-%index%.example.com',
-            'ControllerDeployedServerCount': 3,
-            'ControllerDeployedServerHostnameFormat':
+            'ControllerCount': 3,
+            'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
             'HostnameMap': {
                 'compute-0.example.com': 'compute-0.example.com',
@@ -913,11 +915,11 @@ class TestExpandRoles(base.TestCase):
             }],
             result['instances'])
         self.assertEqual({
-            'ControllerDeployedServerCount': 2,
+            'ControllerCount': 2,
             'ControllerRemovalPolicies': [
                 {'resource_list': [1, 2]}
             ],
-            'ControllerDeployedServerHostnameFormat':
+            'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
             'HostnameMap': {
                 'overcloud-controller-0': 'overcloud-controller-0',
@@ -980,11 +982,11 @@ class TestExpandRoles(base.TestCase):
             }],
             result['instances'])
         self.assertEqual({
-            'ControllerDeployedServerCount': 4,
+            'ControllerCount': 4,
             'ControllerRemovalPolicies': [
                 {'resource_list': [1, 2]}
             ],
-            'ControllerDeployedServerHostnameFormat':
+            'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
             'HostnameMap': {
                 'overcloud-controller-0': 'overcloud-controller-0',
@@ -1052,11 +1054,11 @@ class TestExpandRoles(base.TestCase):
             }],
             result['instances'])
         self.assertEqual({
-            'ControllerDeployedServerCount': 2,
+            'ControllerCount': 2,
             'ControllerRemovalPolicies': [
                 {'resource_list': [1, 2]}
             ],
-            'ControllerDeployedServerHostnameFormat':
+            'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
             'HostnameMap': {
                 'overcloud-controller-0': 'controller-0',
@@ -1120,11 +1122,11 @@ class TestExpandRoles(base.TestCase):
             }],
             result['instances'])
         self.assertEqual({
-            'ControllerDeployedServerCount': 2,
+            'ControllerCount': 2,
             'ControllerRemovalPolicies': [
                 {'resource_list': [1, 2]}
             ],
-            'ControllerDeployedServerHostnameFormat':
+            'ControllerHostnameFormat':
                 '%stackname%-controller-%index%',
             'HostnameMap': {
                 'overcloud-controller-0': 'node-0',
