@@ -254,16 +254,16 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_namespace': 'quay.ceph.io/ceph-ci',
                 'ceph_image': 'daemon',
                 'ceph_tag': 'v4.0.13-stable-4.0-nautilus-centos-7-x86_64',
-                'ceph_grafana_namespace': 'quay.io/app-sre',
+                'ceph_grafana_namespace': 'quay.ceph.io/app-sre',
                 'ceph_grafana_image': 'grafana',
-                'ceph_grafana_tag': '5.2.4',
-                'ceph_prometheus_namespace': 'quay.io/prometheus',
+                'ceph_grafana_tag': '5.4.3',
+                'ceph_prometheus_namespace': 'quay.ceph.io/prometheus',
                 'ceph_prometheus_image': 'prometheus',
                 'ceph_prometheus_tag': 'v2.7.2',
-                'ceph_alertmanager_namespace': 'quay.io/prometheus',
+                'ceph_alertmanager_namespace': 'quay.ceph.io/prometheus',
                 'ceph_alertmanager_image': 'alertmanager',
                 'ceph_alertmanager_tag': 'v0.16.2',
-                'ceph_node_exporter_namespace': 'quay.io/prometheus',
+                'ceph_node_exporter_namespace': 'quay.ceph.io/prometheus',
                 'ceph_node_exporter_image': 'node-exporter',
                 'ceph_node_exporter_tag': 'v0.17.0',
                 'name_prefix': 'centos-binary-',
@@ -281,16 +281,16 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_namespace': 'quay.ceph.io/ceph-ci',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
-                'ceph_grafana_namespace': 'quay.io/app-sre',
+                'ceph_grafana_namespace': 'quay.ceph.io/app-sre',
                 'ceph_grafana_image': 'grafana',
-                'ceph_grafana_tag': '5.2.4',
-                'ceph_prometheus_namespace': 'quay.io/prometheus',
+                'ceph_grafana_tag': '5.4.3',
+                'ceph_prometheus_namespace': 'quay.ceph.io/prometheus',
                 'ceph_prometheus_image': 'prometheus',
                 'ceph_prometheus_tag': 'v2.7.2',
-                'ceph_alertmanager_namespace': 'quay.io/prometheus',
+                'ceph_alertmanager_namespace': 'quay.ceph.io/prometheus',
                 'ceph_alertmanager_image': 'alertmanager',
                 'ceph_alertmanager_tag': 'v0.16.2',
-                'ceph_node_exporter_namespace': 'quay.io/prometheus',
+                'ceph_node_exporter_namespace': 'quay.ceph.io/prometheus',
                 'ceph_node_exporter_image': 'node-exporter',
                 'ceph_node_exporter_tag': 'v0.17.0',
                 'name_prefix': 'prefix-',
@@ -338,16 +338,16 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'ceph_namespace': 'quay.ceph.io/ceph-ci',
                 'ceph_image': 'ceph-daemon',
                 'ceph_tag': 'latest',
-                'ceph_grafana_namespace': 'quay.io/app-sre',
+                'ceph_grafana_namespace': 'quay.ceph.io/app-sre',
                 'ceph_grafana_image': 'grafana',
-                'ceph_grafana_tag': '5.2.4',
-                'ceph_prometheus_namespace': 'quay.io/prometheus',
+                'ceph_grafana_tag': '5.4.3',
+                'ceph_prometheus_namespace': 'quay.ceph.io/prometheus',
                 'ceph_prometheus_image': 'prometheus',
                 'ceph_prometheus_tag': 'v2.7.2',
-                'ceph_alertmanager_namespace': 'quay.io/prometheus',
+                'ceph_alertmanager_namespace': 'quay.ceph.io/prometheus',
                 'ceph_alertmanager_image': 'alertmanager',
                 'ceph_alertmanager_tag': 'v0.16.2',
-                'ceph_node_exporter_namespace': 'quay.io/prometheus',
+                'ceph_node_exporter_namespace': 'quay.ceph.io/prometheus',
                 'ceph_node_exporter_image': 'node-exporter',
                 'ceph_node_exporter_tag': 'v0.17.0',
                 'name_prefix': 'prefix-',
@@ -451,28 +451,28 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync(self):
         remove_images = [
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-opendaylight:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-ovn-northd:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary-ovn-'
+             'imagename': 'quay.io/tripleotrain/centos-binary-ovn-'
                           'controller:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary-ovn-'
+             'imagename': 'quay.io/tripleotrain/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary-ovn-'
+             'imagename': 'quay.io/tripleotrain/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             remove_images=remove_images)
@@ -482,25 +482,25 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         # remove neutron-server image reference from tripleo_containers.yaml
         remove_images = [
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-server:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-server-ovn:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-ovn-northd:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary-ovn-'
+             'imagename': 'quay.io/tripleotrain/centos-binary-ovn-'
                           'controller:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary-ovn-'
+             'imagename': 'quay.io/tripleotrain/centos-binary-ovn-'
                           'nb-db-server:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary-ovn-'
+             'imagename': 'quay.io/tripleotrain/centos-binary-ovn-'
                           'sb-db-server:current-tripleo'},
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-metadata-agent-ovn:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='odl', remove_images=remove_images)
@@ -510,13 +510,13 @@ class TestKollaImageBuilderTemplate(base.TestCase):
         # remove neutron-server image reference from tripleo_containers.yaml
         remove_images = [
             {'image_source': 'tripleo',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-server:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-             'imagename': 'docker.io/tripleotrain/centos-binary'
+             'imagename': 'quay.io/tripleotrain/centos-binary'
                           '-opendaylight:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             neutron_driver='ovn', remove_images=remove_images)
@@ -525,19 +525,19 @@ class TestKollaImageBuilderTemplate(base.TestCase):
     def test_container_images_yaml_in_sync_for_rhel(self):
         remove_images = [
             {'image_source': 'tripleo',
-                'imagename': 'docker.io/tripleotrain/centos-binary'
+                'imagename': 'quay.io/tripleotrain/centos-binary'
                              '-neutron-server:current-tripleo'},
             {'image_source': 'kolla',
-                'imagename': 'docker.io/tripleotrain/centos-binary'
+                'imagename': 'quay.io/tripleotrain/centos-binary'
                              '-neutron-server-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-                'imagename': 'docker.io/tripleotrain/centos-binary'
+                'imagename': 'quay.io/tripleotrain/centos-binary'
                              '-opendaylight:current-tripleo'},
             {'image_source': 'kolla',
-                'imagename': 'docker.io/tripleotrain/centos-binary'
+                'imagename': 'quay.io/tripleotrain/centos-binary'
                              '-fluentd:current-tripleo'},
             {'image_source': 'kolla',
-                'imagename': 'docker.io/tripleotrain/centos-binary'
+                'imagename': 'quay.io/tripleotrain/centos-binary'
                              '-sensu-client:current-tripleo'}]
         self._test_container_images_yaml_in_sync_helper(
             rhel_containers=True, neutron_driver='ovn',
